@@ -36,23 +36,20 @@ class Testr:
     def install(self):
         options = self.options
         dest = []
-        eggs, ws = self.egg.working_set(('testrepository', ))
+        reqs = []
+        if options.get('test-packages', ''):
+            reqs.append('python-subunit>0.0.5')
+            reqs.append('discover')
+            reqs.append('testtools>0.9.3')
+        reqs.append('testrepository')
+        eggs, ws = self.egg.working_set(reqs)
 
         test_paths = [ws.find(pkg_resources.Requirement.parse(spec)).location
                       for spec in eggs]
 
         wd = options.get('working-directory', '')
         if wd:
-            wd = os.path.abspath(wd)
-
-            if self.egg._relative_paths:
-                wd = _relativize(self.egg._relative_paths, wd)
-                test_paths = [_relativize(self.egg._relative_paths, p)
-                              for p in test_paths]
-            else:
-                wd = repr(wd)
-                test_paths = map(repr, test_paths)
-
+            wd = repr(os.path.abspath(wd))
             initialization = initialization_template % wd
         else:
             initialization = ""
@@ -68,7 +65,7 @@ class Testr:
         if not wd:
             base_dir = self.buildout['buildout']['directory']
             if self.egg._relative_paths:
-                _relativize(self.egg._relative_paths, base_dir)
+                base_dir = _relativize(self.egg._relative_paths, base_dir)
             initialization += "['-d%s'] + " % base_dir
         if defaults:
             initialization += "(%s) + " % defaults
@@ -89,6 +86,31 @@ class Testr:
             relative_paths = self.egg._relative_paths,
             ))
 
+        if options.get('test-packages', ''):
+            dest.extend(zc.buildout.easy_install.scripts(
+                reqs, ws, options['executable'],
+                self.buildout['buildout']['bin-directory'],
+                interpreter=self.name+"py",
+                extra_paths=self.egg.extra_paths,
+                initialization = initialization,
+                relative_paths = self.egg._relative_paths,
+                ))
+            target_conf_path = os.path.join(
+                self.buildout['buildout']['directory'], '.testr.conf')
+            config_values = {}
+            config_values['test_packages'] = options.get('test-packages')
+            interpreter = self.name+"py"
+            interpreter_path = os.path.join(
+                self.buildout['buildout']['bin-directory'], interpreter)
+            if self.egg._relative_paths:
+                interpreter_path = _relativize(
+                    self.egg._relative_paths, interpreter_path)
+            config_values['interpreter'] = interpreter_path
+            configuration = configuration_template % config_values
+            with open(target_conf_path, 'w') as f:
+                f.write(configuration)
+            dest.append(target_conf_path)
+
         return dest
 
     update = install
@@ -105,6 +127,11 @@ os.chdir(%s)
 env_template = """os.environ['%s'] = %r
 """
 
+configuration_template = """[DEFAULT]
+test_command=%(interpreter)s -m subunit.run $IDLIST
+test_id_list_default=discover %(test_packages)s
+"""
+
 def _relativize(base, path):
     base += os.path.sep
     if path.startswith(base):
